print("*Loaded HV Maps Capital City Renamer script*");

-- get option from advanced setup screen.
local bTrueStarts = MapConfiguration.GetValue("HV_Maps_TrueStartRegions") or false;


-- get strings for size and type of map
local sMapType = "BRITISH_ISLES";	
local iMapSize = Map.GetMapSize()
local sMapSize = "";


if iMapSize == 3 then -- STANDARD Size
	sMapSize = "MAPSIZE_STANDARD";
	--sMapSize = "MAPSIZE_PTOLOMY_STANDARD";		

elseif iMapSize == 2 then -- SMALL Size
	sMapSize = "MAPSIZE_SMALL";	

elseif	iMapSize == 1 then -- TINY size
	sMapSize = "MAPSIZE_TINY";	

else
	print("Error, invalid map size for British Isles.");
end

function HV_Maps_TrueStartCapitals(iPlayerID, iCityID)
	
	-- if True Start Regions option is off, do nothing.
	if bTrueStarts then
		-- get info about the city, and the player who founded it.
		local pPlayer = Players[iPlayerID];
		local pPlayerConfig = PlayerConfigurations[iPlayerID];
		local sPlayerType = pPlayerConfig:GetCivilizationTypeName();
		local sLeaderType = pPlayerConfig:GetLeaderTypeName();
		local pCity = pPlayer:GetCities():FindID( iCityID );
		local sOldName = Locale.Lookup( pCity:GetName() );
	
		local sLeaderCapitalName = "";
		local sCivCapitalName = "";
		
		-- do nothing unless the founded city is a capital.
		if pCity == pPlayer:GetCities():GetCapitalCity() then
			print("Capital City (" .. sOldName .. ") was founded by player " .. iPlayerID .. " (" .. sPlayerType .. ")" );
			
			-- loop through true-starts sql table to see if there's an entry (or several) for this civ
			for Row in GameInfo.HV_Map_TrueStartRegion() do 
				
				-- find an entry valid for this map and civ.
				if (Row.MapType == sMapType or Row.MapType == nil) and (Row.MapSize == sMapSize or Row.MapSize == nil) and Row.Civilization == sPlayerType and Row.OverrideCapital ~= nil then
					-- is it specific to this leader? Or generic, for any leader of this civ?
					if Row.Leader == sLeaderType then
						sLeaderCapitalName = Row.OverrideCapital;
					elseif Row.Leader == nil then
						sCivCapitalName = Row.OverrideCapital;
					end
				end
			end
			
			-- leader-specific name takes precedence if we found one.
			local sNewName = "";
			
			if sLeaderCapitalName ~= "" then
				sNewName = sLeaderCapitalName;
				--print("Leader-specific capital name override: " .. sNewName);
			elseif sCivCapitalName ~= nil then
				sNewName = sCivCapitalName;
				--print("Capital name override: " .. sNewName);
			end
			
			-- if we found a capital-override name in the table, try to rename the city.
			if sNewName ~= "" then			
				-- if this name is already taken by another city, do nothing
				if HV_Maps_NameAlreadyTaken(sNewName) then
					print("Cannot rename " .. sOldName .. " because city named " .. sNewName .. " already exists on map");
				else
					-- rename the city
					pCity:SetName(sNewName);
					print("Renamed " .. sOldName .. " to " .. sNewName);
				end
			end
		end
	end
	
end

-- call this whenever a city is founded or changes ownership.
Events.CityInitialized.Add(HV_Maps_TrueStartCapitals);


-- checks all cities currently on the map, returns true if any of their names matches the input string.
function HV_Maps_NameAlreadyTaken (sDesiredName)
	-- get number of players in the game
	local iNumMajorPlayers = PlayerManager.GetAliveMajorsCount();
	local iNumMinorPlayers = PlayerManager.GetAliveMinorsCount(); 
	local iNumPlayersTotal = iNumMajorPlayers + iNumMinorPlayers;
	
	-- loop through all players
	--for index, iPlayerID in pairs(Players) do
	for iPlayerID = 0, iNumPlayersTotal-1, 1 do -- first player is index 0, not index 1;
		local pPlayer = Players[iPlayerID];
		local pPlayerConfig = PlayerConfigurations[iPlayerID];
		local sPlayerType = pPlayerConfig:GetCivilizationTypeName();
		local pCities = pPlayer:GetCities();
		
		-- loop through all cities this player owns
		for index, pCity in pCities:Members() do	
			local sCityName = Locale.Lookup( pCity:GetName() );
			
			-- return true if this city name matches input.
			if sCityName == sDesiredName then
				return true;
			end
		end	
	end

	-- if we didn't find a match, return false.
	return false;
end